@@ -28,10 +28,10 @@
 
 #include "exchange-config-listener.h"
 
-#include "exchange-account.h"
-#include "e-folder-exchange.h"
-#include "e2k-marshal.h"
-#include "e2k-uri.h"
+#include <exchange-account.h>
+#include <e-folder-exchange.h>
+#include <e2k-marshal.h>
+#include <e2k-uri.h>
 #include "mail-stub-listener.h"
 
 #include <e-util/e-dialog-utils.h>
@@ -801,7 +801,7 @@ account_added (EAccountList *account_list, EAccount *account)
 
 	g_signal_emit (config_listener, signals[EXCHANGE_ACCOUNT_CREATED], 0,
 		       exchange_account);
-	add_sources (exchange_account);
+	//add_sources (exchange_account);
 	exchange_account_connect (exchange_account);
 }
 
